@@ -7,6 +7,8 @@
 /* For alloca, when using KaRaMeL's -falloca */
 #if (defined(_WIN32) || defined(_WIN64))
 #include <malloc.h>
+#elif (defined(sun))
+#include <alloca.h>
 #endif
 
 /* If some globals need to be initialized before the main, then karamel will
