@@ -24,7 +24,6 @@
 #define TLS13_ECH_VERSION 0xfe0d
 #define TLS13_ECH_SIGNAL_LEN 8
 #define TLS13_ECH_AEAD_TAG_LEN 16
-#define TLS13_ECH_GREASE_SNI_LEN 100
 
 static const char kHpkeInfoEch[] = "tls ech";
 static const char hHkdfInfoEchConfigID[] = "tls ech config id";
@@ -50,7 +49,7 @@ struct sslEchConfigContentsStr {
 };
 
 /* ECH Information needed by a server to process a second CH after a
- * HelloRetryRequest is sent. This data is stored in the cookie. 
+ * HelloRetryRequest is sent. This data is stored in the cookie.
  */
 struct sslEchCookieDataStr {
     PRBool previouslyOffered;
@@ -58,7 +57,7 @@ struct sslEchCookieDataStr {
     HpkeKdfId kdfId;
     HpkeAeadId aeadId;
     HpkeContext *hpkeCtx;
-    sslBuffer signal;
+    PRUint8 signal[TLS13_ECH_SIGNAL_LEN];
 };
 
 struct sslEchConfigStr {
@@ -83,6 +82,8 @@ struct sslEchXtnStateStr {
     PRUint8 *payloadStart;    /* Server: Start of ECH Payload*/
 };
 
+SEC_BEGIN_PROTOS
+
 SECStatus SSLExp_EncodeEchConfigId(PRUint8 configId, const char *publicName, unsigned int maxNameLen,
                                    HpkeKemId kemId, const SECKEYPublicKey *pubKey,
                                    const HpkeSymmetricSuite *hpkeSuites, unsigned int hpkeSuiteCount,
@@ -95,6 +96,8 @@ SECStatus SSLExp_SetServerEchConfigs(PRFileDesc *fd,
                                      const PRUint8 *echConfigs, unsigned int numEchConfigs);
 SECStatus SSLExp_RemoveEchConfigs(PRFileDesc *fd);
 
+SEC_END_PROTOS
+
 SECStatus tls13_ClientSetupEch(sslSocket *ss, sslClientHelloType type);
 SECStatus tls13_ConstructClientHelloWithEch(sslSocket *ss, const sslSessionID *sid,
                                             PRBool freshSid, sslBuffer *chOuterBuf,
